@@ -1,3 +1,21 @@
+/*
+ * Copyright 2010 Felipe Crochik <foss@crochik.com>
+ * All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 #include "geolocation.h"
 
 #include <QDebug>
@@ -23,11 +41,11 @@ GeoLocation::~GeoLocation() {
     if ( m_pSatellite ) { m_pSatellite->stopUpdates(); delete m_pSatellite; }
 }
 
-double GeoLocation::latitude() {
+double GeoLocation::latitude() const {
     return m_lastLocation.coordinate().latitude();
 }
 
-double GeoLocation::longitude() {
+double GeoLocation::longitude() const {
     return m_lastLocation.coordinate().longitude();
 }
 
