@@ -86,7 +86,7 @@ MainWindow::MainWindow(QWidget *parent) :
 
     ui->setupUi(this);
 
-    m_startAddress.setCoordinates( 35.8185 ,  -78.8641);
+    m_startAddress.setCoordinates( 40.7527700 ,  -73.9765000); // grand central station ny
 
     init();
 }
@@ -581,12 +581,12 @@ void MainWindow::search() {
     m_destination.setCoordinates(bus.latitude(), bus.longitude());
     m_destination.setDescription(
         // assemble address
-        QString("%1, %2, %3, %4 (%5)").arg(
+        QString("%1, %2, %3, %4").arg( //"%1, %2, %3, %4 (%5)"
                 bus.m_address.address(),
                 bus.m_address.city(),
                 bus.m_address.region(),
-                bus.m_address.country(),
-                bus.description()
+                bus.m_address.country() // ,
+                // bus.description()
         )
         // use lat/long (it only seems to matter for v3 of the api)
         // QString("%1 %2").arg(bus.latitudeStr(), bus.longitudeStr())
